"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.quadtree = quadtree;
const q_tree_1 = require("./q-tree");
/**
 * Create a quadtree for a given area.
 *
 * @param area The region-bounds of this quadtree.
 * @param boundsFn Child bounds predicate.
 * @param options
 * @typeParam T The type of children of this quadtree contains.
 *
 * @example A simple quadtree
 *
 * ```ts
 * interface Rectangle {
 *   x: number;
 *   y: number;
 *   width: number;
 *   height: number;
 * }
 *
 * const rectBounds = ({ x, y, width, height }: Rectangle) =>
 *   [x, y, x + width, r.y + height];
 *
 * const qt = quadtree([0,0,1000,1000], rectBounds);
 *
 * // Add a rectangle
 * qt.insert([20, 20, 50, 50]);
 *
 * // Collect items
 * const results = qt.collect([0, 0, 100, 100]);
 * ```
 *
 * @example Using advanced options
 *
 * ```ts
 * const qt = quadtree(
 *   [0,0,1000,1000],
 *   rectBounds,
 *   {
 *     maxDepth: 4,
 *     maxChildren: 50
 *   }
 * );
 * ```
 *
 * @example Using DOMRect with quadtree
 *
 * ```ts
 * const qt = quadtree<DOMRect>(
 *   [0, 0, 1000, 1000],
 *   ({ left, top, right, bottom }) => [left, top, right, bottom],
 * );
 * ```
 */
function quadtree(area, boundsFn, options = {}) {
    const quadCache = new WeakMap();
    return new q_tree_1.qTree(area, options, boundsFn, quadCache);
}
//# sourceMappingURL=factory.js.map